==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/analysisservices/kotlin/inputs/IPv4FirewallRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.analysisservices.kotlin.inputs

import com.pulumi.azurenative.analysisservices.inputs.IPv4FirewallRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The detail of firewall rule.
 * @property firewallRuleName The rule name.
 * @property rangeEnd The end range of IPv4.
 * @property rangeStart The start range of IPv4.
 */
public data class IPv4FirewallRuleArgs(
    public val firewallRuleName: Output<String>? = null,
    public val rangeEnd: Output<String>? = null,
    public val rangeStart: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.analysisservices.inputs.IPv4FirewallRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.analysisservices.inputs.IPv4FirewallRuleArgs =
        com.pulumi.azurenative.analysisservices.inputs.IPv4FirewallRuleArgs.builder()
            .firewallRuleName(firewallRuleName?.applyValue({ args0 -> args0 }))
            .rangeEnd(rangeEnd?.applyValue({ args0 -> args0 }))
            .rangeStart(rangeStart?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IPv4FirewallRuleArgs].
 */
@PulumiTagMarker
public class IPv4FirewallRuleArgsBuilder internal constructor() {
    private var firewallRuleName: Output<String>? = null

    private var rangeEnd: Output<String>? = null

    private var rangeStart: Output<String>? = null

    /**
     * @param value The rule name.
     */
    @JvmName("ntskngrdfvjtonhd")
    public suspend fun firewallRuleName(`value`: Output<String>) {
        this.firewallRuleName = value
    }

    /**
     * @param value The end range of IPv4.
     */
    @JvmName("tutjwkmonweanxca")
    public suspend fun rangeEnd(`value`: Output<String>) {
        this.rangeEnd = value
    }

    /**
     * @param value The start range of IPv4.
     */
    @JvmName("sgkdaopvdjdtbhhx")
    public suspend fun rangeStart(`value`: Output<String>) {
        this.rangeStart = value
    }

    /**
     * @param value The rule name.
     */
    @JvmName("jjkroygdoffrsyfd")
    public suspend fun firewallRuleName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.firewallRuleName = mapped
    }

    /**
     * @param value The end range of IPv4.
     */
    @JvmName("rhmdkiejuosoyciv")
    public suspend fun rangeEnd(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeEnd = mapped
    }

    /**
     * @param value The start range of IPv4.
     */
    @JvmName("ilnaepouecfjwepu")
    public suspend fun rangeStart(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeStart = mapped
    }

    internal fun build(): IPv4FirewallRuleArgs = IPv4FirewallRuleArgs(
        firewallRuleName = firewallRuleName,
        rangeEnd = rangeEnd,
        rangeStart = rangeStart,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/analysisservices/kotlin/inputs/IPv4FirewallRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.analysisservices.kotlin.inputs

import com.pulumi.azurenative.analysisservices.inputs.IPv4FirewallRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The detail of firewall rule.
 * @property firewallRuleName The rule name.
 * @property rangeEnd The end range of IPv4.
 * @property rangeStart The start range of IPv4.
 */
public data class IPv4FirewallRuleArgs(
    public val firewallRuleName: Output<String>? = null,
    public val rangeEnd: Output<String>? = null,
    public val rangeStart: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.analysisservices.inputs.IPv4FirewallRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.analysisservices.inputs.IPv4FirewallRuleArgs =
        com.pulumi.azurenative.analysisservices.inputs.IPv4FirewallRuleArgs.builder()
            .firewallRuleName(firewallRuleName?.applyValue({ args0 -> args0 }))
            .rangeEnd(rangeEnd?.applyValue({ args0 -> args0 }))
            .rangeStart(rangeStart?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IPv4FirewallRuleArgs].
 */
@PulumiTagMarker
public class IPv4FirewallRuleArgsBuilder internal constructor() {
    private var firewallRuleName: Output<String>? = null

    private var rangeEnd: Output<String>? = null

    private var rangeStart: Output<String>? = null

    /**
     * @param value The rule name.
     */
    @JvmName("kqgedsotharoaygc")
    public suspend fun firewallRuleName(`value`: Output<String>) {
        this.firewallRuleName = value
    }

    /**
     * @param value The end range of IPv4.
     */
    @JvmName("livblmtswysvbmiq")
    public suspend fun rangeEnd(`value`: Output<String>) {
        this.rangeEnd = value
    }

    /**
     * @param value The start range of IPv4.
     */
    @JvmName("tnekdcgoxjnyulci")
    public suspend fun rangeStart(`value`: Output<String>) {
        this.rangeStart = value
    }

    /**
     * @param value The rule name.
     */
    @JvmName("jkxfwqwpqqgnndwi")
    public suspend fun firewallRuleName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.firewallRuleName = mapped
    }

    /**
     * @param value The end range of IPv4.
     */
    @JvmName("bvnmidcepakxddcn")
    public suspend fun rangeEnd(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeEnd = mapped
    }

    /**
     * @param value The start range of IPv4.
     */
    @JvmName("xgxkutawetgjxnty")
    public suspend fun rangeStart(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeStart = mapped
    }

    internal fun build(): IPv4FirewallRuleArgs = IPv4FirewallRuleArgs(
        firewallRuleName = firewallRuleName,
        rangeEnd = rangeEnd,
        rangeStart = rangeStart,
    )
}
